﻿using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Drawing;
using System.Data;
using System.Linq;
using System.Text;
using System.Windows.Forms;
using Infragistics.Win;
using Infragistics.Win.UltraWinGrid;

namespace UltraGridZeroValue
{
    public partial class KitMaintenanceView : UserControl
    {
        private ValueList _valueListParts;

        public KitMaintenanceView()
        {
            InitializeComponent();
            _valueListParts = new ValueList { FormatString = string.Empty };
            _valueListParts.ValueListItems.Add(1, "First item");
            ValueListItem item = new ValueListItem(2, "Second item");
            _valueListParts.ValueListItems.Add(item);
                        
            this.grdKit.SetDataBinding(this.GetData(), "table1");
            setupHandlers();
        }

        private void grdKit_InitializeLayout(object sender, InitializeLayoutEventArgs e)
        {
            e.Layout.GroupByBox.Hidden = true;
            e.Layout.TabNavigation = TabNavigation.NextControlOnLastCell;

            // Resize columns to width of grid
            e.Layout.AutoFitStyle = AutoFitStyle.ResizeAllColumns;

            e.Layout.Override.CellClickAction = CellClickAction.Edit;
            e.Layout.Override.AllowAddNew = AllowAddNew.FixedAddRowOnTop;
            e.Layout.Override.AllowUpdate = DefaultableBoolean.True;
            e.Layout.Override.AllowDelete = DefaultableBoolean.True;

            UltraGridBand bandKit = e.Layout.Bands[0];
            UltraGridBand bandParts = e.Layout.Bands[1];

            // Make row selectors visible
            bandKit.Override.RowSelectors = DefaultableBoolean.True;
            // Customize the appearance of the row selectors.
            e.Layout.Override.RowSelectorAppearance.BackColor = Color.Cyan;

            // Hide columns parent band
            bandKit.Columns["Id"].Hidden = true;

            // Hide columns child band
            bandParts.Columns["Id"].Hidden = true;
            bandParts.Columns["KitId"].Hidden = true;

            // Set Column descriptions, widths & appearances for child band
            bandParts.Columns["PartId"].Width = 450;
            // band.Columns["PartId"].SortIndicator = SortIndicator.Ascending;
            bandParts.Columns["PartId"].Header.Caption = "Description";
            bandParts.Columns["PartId"].Style = Infragistics.Win.UltraWinGrid.ColumnStyle.DropDownList;
            bandParts.Columns["PartId"].ValueList = _valueListParts;

            bandParts.Columns["Quantity"].CellAppearance.TextHAlign = HAlign.Right;
            bandParts.Columns["Quantity"].Format = "###,##0.00";
            bandParts.Columns["Quantity"].MaskInput = "999999.99";
            bandParts.Columns["Quantity"].Width = 70;
        }

        private void setupHandlers()
        {
            grdKit.InitializeLayout += grdKit_InitializeLayout;
        }

        private DataSet GetData()
        {
            DataSet ds = new DataSet();
            DataTable t1 = ds.Tables.Add("table1");
            t1.Columns.Add("Id", typeof(int)).AutoIncrement = true;
            t1.Columns.Add("Parent", typeof(string));

            DataTable t2 = ds.Tables.Add("table2");
            t2.Columns.Add("Id", typeof(int)).AutoIncrement = true;
            t2.Columns.Add("KitId", typeof(int));
            t2.Columns.Add("PartId", typeof(int));
            t2.Columns.Add("Quantity", typeof(double));

            ds.Relations.Add(t1.Columns["Id"], t2.Columns["KitId"]);

            ds = this.AddData(ds);

            return ds;
        }

        private DataSet AddData(DataSet ds)
        {
            ds.Tables["table1"].Rows.Add(new object[] { null, "Parent" });
            ds.Tables["table2"].Rows.Add(new object[] { null, 0, null, 0 });

            return ds;
        }
    }
}
